@@ -1,4 +1,3 @@
-
 ###########################################################################
 #
 # this module meant to provide intuitive functions to work with xml files
@@ -6,18 +5,18 @@
 ###########################################################################
 
 
-# will return a list of nodes specified by an attribute key and an attribute value
-def get_nodes(xml_file, node_tag, node_att_name=None, node_att_val=None):
+# will search in all of the direct children of the root
+def get_root_direct_children_nodes(xml_file, node_tag, node_att_name=None, node_att_val=None):
     root = xml_file.getroot()
     if root.tag == node_tag:
         return [root]
+    return _get_nodes(root, node_tag, node_att_name, node_att_val)
+
+
+# will return a list of nodes specified by an attribute key and an attribute value from a parent node
+def get_child_nodes(node_parent, node_tag, node_att_name=None, node_att_val=None):
     selector = node_tag
-    if node_att_name is not None:
-        if node_att_val is not None:
-            selector = node_tag + "/[@" + node_att_name + "='" + node_att_val + "']"
-        else:
-            selector = node_tag + "/[@" + node_att_name + "]"
-    return root.findall(selector)
+    return _get_nodes(node_parent, node_tag, node_att_name, node_att_val)
 
 
 # will return a list of nodes which doesn't have a specific attribute
@@ -54,10 +53,12 @@ def nodes_to_dict(nodes, att_key):
         nodes_dict[get_node_att(node, att_key)] = get_text_from_node(node)
     return nodes_dict
 
+
 # will return all of the direct children of a given node
 def get_all_direct_child_nodes(node):
     return list(node)
 
+
 # will return the text (inner html) of a given node
 def get_text_from_node(node):
     text = node.text
@@ -65,9 +66,15 @@ def get_text_from_node(node):
         return None
     return node.text
 
-# will return the text from a specific node
-def get_text(xml_file, node_tag, node_att_name=None, node_att_val=None):
-    return get_text_from_node(get_nodes(xml_file, node_tag, node_att_name, node_att_val)[0])
+
+# will return the text from a child node, using the parent node.
+# NOTICE: this function will not crash but return None if the node isn't exists
+def get_text_from_child_node(parent_node, child_node_tag, child_node_att_name=None, child_node_att_val=None):
+    child_nodes = get_child_nodes(parent_node, child_node_tag, child_node_att_name, child_node_att_val)
+    if child_nodes:
+        return get_text_from_node(child_nodes[0])
+    else:
+        return None
 
 
 # will set the text (inner html) in a given node
@@ -142,3 +149,14 @@ def simple_dict_to_xml(xml_dict, root_name, output_path):
 
 def get_root_node(xml_file):
     return xml_file.getroot()
+
+
+# bp code for nodes fetching
+def _get_nodes(node, node_tag, node_att_name=None, node_att_val=None):
+    selector = node_tag
+    if node_att_name is not None:
+        if node_att_val is not None:
+            selector = node_tag + "/[@" + node_att_name + "='" + node_att_val + "']"
+        else:
+            selector = node_tag + "/[@" + node_att_name + "]"
+    return node.findall(selector)
